@@ -8,5 +8,10 @@ process_functions <- list(
   afinn = process_afinn,
   sentence_polarity = process_sentence_polarity,
   loughran = process_loughran,
-  bing = process_bing
+  bing = process_bing,
+  nrc = process_nrc,
+  ag_news = process_ag_news,
+  dbpedia = process_dbpedia,
+  trec = process_trec,
+  imdb = process_imdb
 )
